@@ -99,6 +99,21 @@ def test_download_ranged_http(httpserver, tmpdir):
     validate_test_file(f)
 
 
+def test_regression_download_ranged_http(httpserver, tmpdir):
+    tmpdir = str(tmpdir)
+    httpserver.serve_content('S',
+                             headers={'Content-Disposition': "attachment; filename=testfile.fits",
+                                      'Accept-Ranges': "bytes"})
+    dl = Downloader()
+
+    dl.enqueue_file(httpserver.url, path=Path(tmpdir))
+
+    assert dl.queued_downloads == 1
+
+    f = dl.download()
+    assert len(f.errors) == 0, f.errors
+
+
 def test_download_partial(httpserver, tmpdir):
     tmpdir = str(tmpdir)
     httpserver.serve_content('SIMPLE  = T')
@@ -460,7 +475,7 @@ def test_proxy_passed_as_kwargs_to_get(tmpdir, url, proxy):
     assert patched.called, "`ClientSession._request` not called"
     assert list(patched.call_args) == [('GET', url),
                                        {'allow_redirects': True,
-                                        'timeout': ClientTimeout(total=300, connect=None, sock_read=90, sock_connect=None),
+                                        'timeout': ClientTimeout(total=0, connect=None, sock_read=90, sock_connect=None),
                                         'proxy': proxy
                                         }]
 
